import axios from 'axios';
import store from '@/store/index';
import { Message } from 'element-ui';
import base from './base'; // 导入接口域名列表
import QS from 'qs'


if (process.env.NODE_ENV === 'production') {
    console.log("生产环境");
    /*第二层if，根据.env文件中的VUE_APP_FLAG判断是生产环境还是测试环境*/
    if (process.env.VUE_APP_FLAG === 'pro') {
        //production 生产环境
        axios.defaults.baseURL = base.pro;

    } else {
        //test 测试环境
        axios.defaults.baseURL = base.test;

    }
} else {
    //dev 开发环境
    axios.defaults.baseURL = base.dev;
}
axios.defaults.timeout = 60000;
axios.defaults.headers.post['Content-Type'] = 'application/x-www-form-urlencoded;charset=UTF-8';
axios.interceptors.request.use(
    config => {
        const token = store.state.token;
        token && (config.headers.Authorization = token);
        return config;
    },
    error => {
        return Promise.error(error);
    })


axios.interceptors.response.use(
    response => {
        console.log(response);
        if (response.status === 200) {
            return Promise.resolve(response);
        } else {
            return Promise.reject(response);
        }
    },
    error => {
        console.log(error);
        if (error.response.status) {
            switch (error.response.status) {
                case 401:
                    Message.error("token失效，请重新登陆！");
                    router.replace({
                        path: '/login',
                    });
                    break;

                case 404:
                    Message({
                        message: '网络请求不存在',
                        duration: 1500,
                        forbidClick: true
                    });
                    break;

                default:
                    Message({
                        message: "连接服务器失败",
                        duration: 1500,
                        forbidClick: true,
                        type: 'error'
                    });
            }
            return Promise.reject(error.response);


        }
    })


export default {
    get(url, params) {
        return new Promise((resolve, reject) => {
            axios.get(url, {
                params: params
            })
                .then(res => {
                    resolve(res.data);
                })
                .catch(err => {
                    reject(err.data)
                })
        });
    },
    post(url, params) {
        console.log(url);
        return new Promise((resolve, reject) => {
            axios.post(url, QS.stringify(params))
                .then(res => {
                    console.log(res);
                    resolve(res.data);
                })
                .catch(err => {
                    reject(err.data)
                })
        });
    },
   
}